@@ -12,13 +12,15 @@ from pyway.version import __version__
 
 def migrate(config):
     logger.info('Starting migration process...')
-    Migrate(config).run()
+    output = Migrate(config).run()
+    logger.info(output)
     logger.info('Migration completed.')
 
 
 def validate(config):
     logger.info('Starting validation process')
-    Validate(config).run()
+    output = Validate(config).run()
+    logger.info(output)
     logger.info('Validation completed.')
 
 
@@ -31,7 +33,8 @@ def info(config):
 
 def import_(config):
     logger.info("Importing schema...")
-    Import(config).run()
+    migration_name = Import(config).run()
+    logger.info(f"{migration_name} Imported")
 
 
 def cli():
@@ -42,7 +45,6 @@ def cli():
     (config, parser) = Settings.parse_arguments(config)
 
     # Display version if it exists
-    # TODO: FIX
     if config.version:
         print(f"Version: {__version__}")
         sys.exit(1)
