@@ -40,11 +40,9 @@ class Settings():
         parser.add_argument("cmd", nargs="?", help="info|validate|migrate|import")
 
         config = parse_args(config, parser.parse_args())
-        return config
+        return (config, parser)
 
     def parse_config_file(config):
-        print(f"CONFIG: {config}")
-
         # See if there is a config file
         if os.path.exists(config.config):
             with open(config.config, "r", encoding='utf-8') as ymlfile:
